@@ -10,7 +10,6 @@ except ImportError:
     psutil = None
 
 import pandas as pd
-from pandas.types.common import is_integer_dtype, is_float_dtype
 
 from ...bytes import read_bytes
 from ...bytes.core import write_bytes
@@ -18,10 +17,15 @@ from ...bytes.compression import seekable_files, files as cfiles
 from ...compatibility import PY2, PY3
 from ...delayed import delayed
 
-from ..utils import clear_known_categories
+from ..utils import clear_known_categories, PANDAS_VERSION
 
 from .io import from_delayed
 
+if PANDAS_VERSION >= '0.20.0':
+    from pandas.api.types import is_integer_dtype, is_float_dtype
+else:
+    from pandas.types.common import is_integer_dtype, is_float_dtype
+
 
 delayed = delayed(pure=True)
 
@@ -138,8 +142,10 @@ def text_blocks_to_pandas(reader, block_lists, header, head, kwargs,
                                       dtypes, columns, write_header=False,
                                       enforce=enforce)
         dfs.append(df)
+        rest_kwargs = kwargs.copy()
+        rest_kwargs.pop('skiprows', None)
         for b in blocks[1:]:
-            dfs.append(delayed_pandas_read_text(reader, b, header, kwargs,
+            dfs.append(delayed_pandas_read_text(reader, b, header, rest_kwargs,
                                                 dtypes, columns,
                                                 enforce=enforce))
 
@@ -219,7 +225,8 @@ def read_pandas(reader, urlpath, blocksize=AUTO_BLOCKSIZE, collection=True,
     if kwargs.get('header', 'infer') is None:
         header = b''
     else:
-        header = sample.split(b_lineterminator)[0] + b_lineterminator
+        header_row = kwargs.get('skiprows', 0)
+        header = sample.split(b_lineterminator)[header_row] + b_lineterminator
 
     head = reader(BytesIO(sample), **kwargs)
 
