@@ -85,7 +85,8 @@ def make_timeseries(start, end, dtypes, freq, partition_freq, seed=None):
     divisions = list(pd.DatetimeIndex(start=start, end=end,
                                       freq=partition_freq))
     state_data = random_state_data(len(divisions) - 1, seed)
-    name = 'make-timeseries-' + tokenize(start, end, dtypes, freq, partition_freq)
+    name = 'make-timeseries-' + tokenize(start, end, dtypes, freq,
+                                         partition_freq, state_data)
     dsk = {(name, i): (make_timeseries_part, divisions[i], divisions[i + 1],
                        dtypes, freq, state_data[i])
            for i in range(len(divisions) - 1)}
@@ -191,7 +192,7 @@ def daily_stock(symbol, start, stop, freq=pd.Timedelta(seconds=1),
         s = df.iloc[i]
         part = delayed(generate_day)(s.name, s.loc['Open'], s.loc['High'], s.loc['Low'],
                                      s.loc['Close'], s.loc['Volume'],
-                                     freq=freq, random_state=seeds)
+                                     freq=freq, random_state=seed)
         parts.append(part)
         divisions.append(s.name + pd.Timedelta(hours=9))
 
